@@ -1,5 +1,5 @@
 `exactmean` <- function(x)
 {
     ## Drops NA and NaN values!
-    .Call(dplR.mean, as.double(x[!is.na(x)]))
+    .Call(dplR.exactmean, as.double(x[!is.na(x)]))
 }
