@@ -12,6 +12,14 @@
         sum((y-mean(y))^3) / (length(y)*sd(y)^3)
     }
 
+    kurt <- function(x){
+      y <- x[!is.na(x)]
+      n <- length(y)
+      y2 <- y - mean(y)
+      n * sum(y2^4)/(sum(y2^2)^2) * (1 - 1/n)^2 - 3
+    }
+
+    
     yr <- as.numeric(row.names(rwl))
     series.stats <- data.frame(series=names(rwl))
     rwl2 <- as.matrix(rwl)
@@ -23,6 +31,7 @@
     series.stats$median <- colMedians(rwl2, na.rm=TRUE)
     series.stats$stdev <- colSds(rwl2, na.rm=TRUE)
     series.stats$skew <- apply(rwl2, 2, skew)
+    series.stats$kurtosis <- apply(rwl2, 2, kurt)
     #series.stats$sens1 <- apply(rwl2, 2, sens1)
     #series.stats$sens2 <- apply(rwl2, 2, sens2)
     series.stats$gini <- apply(rwl2, 2, gini.coef)
